import { ShopLoadingSkeleton } from "@/components/common/loading-skeleton";
import Footer from "@/components/layout/footer";
import Header from "@/components/layout/header-2/header-2";
import Ads from "@/components/sections/home/ads";
import ArrivalProducts from "@/components/sections/home/arrival-products";
import Categories from "@/components/sections/home/categories";
import BestSellingServices from "@/components/sections/services/best-selling-services";
import PageBreadcrump from "@/components/shared/testing/page-breadcrump";
import { getClient } from "@/lib/react-query";
import { fetchBasicInfo } from "@/servers/actions/basicinfo-action";
import { LocaleParams } from "@/types/params";
import { dehydrate, HydrationBoundary } from "@tanstack/react-query";
import { Suspense } from "react";

async function ServicesPage({ params }: { params: LocaleParams }) {
	const { locale } = await params;

	const breadcrumbItems = [
		{
			href: "/",
			label: {
				en: "Home",
				ar: "الرئيسية",
			},
		},
		{
			href: "/services",
			label: {
				en: "Our Services",
				ar: "خدماتنا",
			},
		},
	];

	const queryClient = getClient();
	await Promise.all([
		queryClient.prefetchQuery({ queryKey: ["basicInfo"], queryFn: fetchBasicInfo }),
	]);

	return (
		<HydrationBoundary state={dehydrate(queryClient)}>
			<main className="block overflow-hidden text-gray-700">
				<Header />
				<Suspense fallback={<ShopLoadingSkeleton locale={locale} />}>
					<PageBreadcrump
						backgroundUrl={"/heros/services.png"}
						locale={locale}
						subtitle={{
							en: "Bin Taleb Company",
							ar: "شركة بن طالب",
						}}
						title={{
							en: "Our Services",
							ar: "خدماتنا",
						}}
						breadcrumbItems={breadcrumbItems}
					/>
					<BestSellingServices />
					<div className="">
						<div className="mx-auto w-full max-w-10xl">
							<ArrivalProducts />
							<Categories />
						</div>
						<Ads />
						<Footer />
					</div>
				</Suspense>
			</main>
		</HydrationBoundary>
	);
}

export default ServicesPage;
